pub struct KeyValue {
pub key: Rc<str>,
pub value: Expression,
pub guard: Option<Expression>,
}Expand description
An entry of a dictionary expression.
Fields
key: Rc<str>The string value associated with the Ryan value.
value: ExpressionThe expression that evaluates to the value of this association.
guard: Option<Expression>An optional if guard. If the supplied expression evaluates to false, the
current key-value pair is not inserted in the final dictionary.