pub struct PostfixOperation {
pub left: Expression,
pub op: PostfixOperator,
}Expand description
An operation involving a Ryan expression and a postfix operator.
Fields
left: ExpressionThe expression on which the postfix operator is applied.
op: PostfixOperatorThe postfix operator to be applied.